# Based on: https://github.com/gocardless/hutch/blob/master/lib/hutch/config.rb
require 'logger'

module Pipeline
  class UnknownAttributeError < StandardError; end

  # This defines configuration for the pipeline.
  module Config
    def self.initialize(params = {})
      @config = { log_level: Logger::INFO }.merge(params)
    end

    def self.get(attr)
      check_attr(attr)
      user_config[attr]
    end

    def self.set(attr, value)
      check_attr(attr)
      user_config[attr] = value
    end

    class << self
      alias_method :[],  :get
      alias_method :[]=, :set
    end

    def self.check_attr(attr)
      unless user_config.key?(attr)
        fail UnknownAttributeError, "#{attr} is not a valid config attribute"
      end
    end

    def self.user_config
      initialize unless @config
      @config
    end

    def self.method_missing(method, *args, &block)
      attr = method.to_s.sub(/=$/, '').to_sym
      return super unless user_config.key?(attr)

      if method =~ /=$/
        set(attr, args.first)
      else
        get(attr)
      end
    end
  end
end
